
TODO: TODO_80_99_84_41 `intercept` has no suggestions if selected via `func_id`

Via `func_id`:

```
some_command func_id_intercept_invocation intercept

class_function: 1
  envelope_class: class_function [init_value]
  tree_step_0: some_command [init_value]
  tree_step_1: intercept [explicit_offered_arg]
  tree_step_2: ~ [implicit_value]
  tree_step_3: ~ [implicit_value]
  func_state: fs_alpha [implicit_value]
  func_id: func_id_intercept_invocation [explicit_offered_arg]
class_output_format: 1
  envelope_class: class_output_format [init_value]
  output_format: json_format [default_value] overrides: json_format repr_format table_format text_format

[ no func selection ]
```

Via path in the tree:

```
some_command intercept

class_function: 1
  envelope_class: class_function [init_value]
  tree_step_0: some_command [init_value]
  tree_step_1: intercept [init_value]
  tree_step_2: ~ [implicit_value]
  tree_step_3: ~ [implicit_value]
  func_state: fs_alpha [implicit_value]
  func_id: func_id_intercept_invocation [implicit_value]
class_output_format: 1
  envelope_class: class_output_format [init_value]
  output_format: json_format [default_value] overrides: json_format repr_format table_format text_format
class_function: 43

[ func selection ]
```

Note that the same path is selected in both cases so it should select funcs in both cases.

Search TODO to see test cases.

It might be something to do with `jump_tree` (generated via FS_33_76_82_84 composite forest)
having no relevant entry in that case.
